@@ -47,6 +47,7 @@ return array(
 					'admin_password_suggestion' => array(
 						'label' => $lng['customer']['generated_pwd'],
 						'type' => 'text',
+						'visible' => (Settings::Get('panel.password_regex') == ''),
 						'value' => generatePassword(),
 						'visible' => ($result['adminid'] == $userinfo['userid'] ? false : true)
 					),
@@ -73,6 +74,23 @@ return array(
 						'type' => 'text',
 						'mandatory' => true,
 						'value' => $result['email']
+					),
+					'custom_notes' => array(
+						'style' => 'align-top',
+						'label' => $lng['usersettings']['custom_notes']['title'],
+						'desc' => $lng['usersettings']['custom_notes']['description'],
+						'type' => 'textarea',
+						'cols' => 60,
+						'rows' => 12,
+						'value' => $result['custom_notes']
+					),
+					'custom_notes_show' => array(
+						'label' => $lng['usersettings']['custom_notes']['show'],
+						'type' => 'checkbox',
+						'values' => array(
+							array ('label' => $lng['panel']['yes'], 'value' => '1')
+						),
+						'value' => array($result['custom_notes_show'])
 					)
 				)
 			),
@@ -187,18 +205,10 @@ return array(
 						'type' => 'textul',
 						'value' => $result['email_quota'],
 						'maxlength' => 9,
-						'visible' => ($settings['system']['mail_quota_enabled'] == '1' ? true : false),
+						'visible' => (Settings::Get('system.mail_quota_enabled') == '1' ? true : false),
 						'mandatory' => true,
 						'ul_field' => $email_quota_ul
 					),
-					'email_autoresponder' => array(
-						'label' => $lng['customer']['autoresponder'],
-						'type' => 'textul',
-						'value' => $result['email_autoresponder'],
-						'maxlength' => 9,
-						'visible' => ($settings['autoresponder']['autoresponder_active'] == '1' ? true : false),
-						'ul_field' => $email_autoresponder_ul
-					),
 					'ftps' => array(
 						'label' => $lng['customer']['ftps'],
 						'type' => 'textul',
@@ -211,7 +221,7 @@ return array(
 						'type' => 'textul',
 						'value' => $result['tickets'],
 						'maxlength' => 9,
-						'visible' => ($settings['ticket']['enabled'] == '1' ? true : false),
+						'visible' => (Settings::Get('ticket.enabled') == '1' ? true : false),
 						'ul_field' => $tickets_ul
 					),
 					'tickets_see_all' => array(
@@ -229,23 +239,6 @@ return array(
 						'maxlength' => 9,
 						'mandatory' => true,
 						'ul_field' => $mysqls_ul
-					),
-					'can_manage_aps_packages' => array(
-						'label' => $lng['aps']['canmanagepackages'],
-						'type' => 'checkbox',
-                        'values' => array(
-                                        array ('label' => $lng['panel']['yes'], 'value' => '1')
-                                    ),
-                        'value' => array($result['can_manage_aps_packages']),
-						'visible' => ($settings['aps']['aps_active'] == '1' ? true : false)
-					),
-					'number_of_aps_packages' => array(
-						'label' => $lng['aps']['numberofapspackages'],
-						'type' => 'textul',
-						'value' => $result['aps_packages'],
-						'maxlength' => 9,
-						'visible' => ($settings['aps']['aps_active'] == '1' ? true : false),
-						'ul_field' => $number_of_aps_packages_ul
 					)
 				)
 			)
