@@ -17,19 +17,15 @@
  *
  */
 
-function getLanguages()
-{
-	global $db, $theme;
-	
-	$query = 'SELECT * FROM `' . TABLE_PANEL_LANGUAGE . '` ';
-	$result = $db->query($query);
+function getLanguages() {
+
+	$result_stmt = Database::query("SELECT * FROM `" . TABLE_PANEL_LANGUAGE . "` ");
 	$languages_array = array();
 
-	while($row = $db->fetch_array($result))
-	{
-		if(!isset($languages_array[$row['language']])
-		   && !in_array($row['language'], $languages_array))
-		{
+	while ($row = $result_stmt->fetch(PDO::FETCH_ASSOC)) {
+		if (!isset($languages_array[$row['language']])
+			&& !in_array($row['language'], $languages_array)
+		) {
 			$languages_array[$row['language']] = html_entity_decode($row['language']);
 		}
 	}
