@@ -124,6 +124,11 @@ return array (
 					'url' => 'customer_extras.php?page=htaccess',
 					'label' => $lng['menue']['extras']['pathoptions'],
 				),
+			    array (
+			        'url' => 'customer_logger.php?page=log',
+			        'label' => $lng['menue']['logger']['logger'],
+			        'show_element' => ( Settings::Get('logger.enabled') == true )
+			    ),
 			),
 		),
 		'traffic' => array (
@@ -173,16 +178,26 @@ return array (
 					'label' => $lng['admin']['customers'],
 					'required_resources' => 'customers',
 				),
-				array (
-					'url' => 'admin_domains.php?page=domains',
-					'label' => $lng['admin']['domains'],
-					'required_resources' => 'domains',
-				),
 				array (
 					'url' => 'admin_admins.php?page=admins',
 					'label' => $lng['admin']['admins'],
 					'required_resources' => 'change_serversettings',
 				),
+			    array (
+			        'url' => 'admin_domains.php?page=domains',
+			        'label' => $lng['admin']['domains'],
+			        'required_resources' => 'domains',
+			    ),
+			    array (
+			        'url' => 'admin_ipsandports.php?page=ipsandports',
+			        'label' => $lng['admin']['ipsandports']['ipsandports'],
+			        'required_resources' => 'change_serversettings',
+			    ),
+			    array (
+			        'url' => 'admin_settings.php?page=updatecounters',
+			        'label' => $lng['admin']['updatecounters'],
+			        'required_resources' => 'change_serversettings',
+			    ),
 			),
 		),
 		'traffic' => array (
@@ -210,67 +225,76 @@ return array (
 					'label' => $lng['admin']['serversettings'],
 					'required_resources' => 'change_serversettings',
 				),
-				array (
-					'url' => 'admin_settings.php?page=phpinfo',
-					'label' => $lng['admin']['phpinfo'],
-					'required_resources' => 'change_serversettings',
-				),
-				array (
-					'url' => 'admin_apcuinfo.php?page=showinfo',
-					'label' => $lng['admin']['apcuinfo'],
-					'required_resources' => 'change_serversettings',
-					'show_element' => (
-						function_exists('apcu_cache_info') === true
-					),
-				),
-				array (
-					'url' => 'admin_ipsandports.php?page=ipsandports',
-					'label' => $lng['admin']['ipsandports']['ipsandports'],
-					'required_resources' => 'change_serversettings',
-				),
 				array (
 					'url' => 'admin_cronjobs.php?page=overview',
 					'label' => $lng['admin']['cron']['cronsettings'],
 					'required_resources' => 'change_serversettings',
 				),
+			    array (
+			        'url' => 'admin_logger.php?page=log',
+			        'label' => $lng['menue']['logger']['logger'],
+			        'required_resources' => 'change_serversettings',
+			        'show_element' => ( Settings::Get('logger.enabled') == true ),
+			    ),
 				array (
 					'url' => 'admin_settings.php?page=rebuildconfigs',
 					'label' => $lng['admin']['rebuildconf'],
 					'required_resources' => 'change_serversettings',
 				),
-				array (
-					'url' => 'admin_settings.php?page=updatecounters',
-					'label' => $lng['admin']['updatecounters'],
-					'required_resources' => 'change_serversettings',
-				),
-				array (
-					'url' => 'admin_settings.php?page=integritycheck',
-					'label' => $lng['admin']['integritycheck'],
-					'required_resources' => 'change_serversettings',
-				),
-				array (
-					'url' => 'admin_phpsettings.php?page=overview',
-					'label' => $lng['menue']['phpsettings']['maintitle'],
-					'show_element' => (
-						Settings::Get('system.mod_fcgid') == true ||
-						Settings::Get('phpfpm.enabled') == true
-					),
-				),
+			    array (
+			        'url' => 'admin_autoupdate.php?page=overview',
+			        'label' => $lng['admin']['autoupdate'],
+			        'required_resources' => 'change_serversettings',
+			    ),
 			),
 		),
+	    'server_php' => array (
+	        'label' => $lng['admin']['server_php'],
+	        'required_resources' => 'change_serversettings',
+	        'elements' => array (
+	            array (
+	                'url' => 'admin_phpsettings.php?page=overview',
+	                'label' => $lng['menue']['phpsettings']['maintitle'],
+	                'show_element' => (
+	                    Settings::Get('system.mod_fcgid') == true ||
+	                    Settings::Get('phpfpm.enabled') == true
+	                ),
+	            ),
+	            array (
+	                'url' => 'admin_settings.php?page=phpinfo',
+	                'label' => $lng['admin']['phpinfo'],
+	                'required_resources' => 'change_serversettings',
+	            ),
+	            array (
+	                'url' => 'admin_apcuinfo.php?page=showinfo',
+	                'label' => $lng['admin']['apcuinfo'],
+	                'required_resources' => 'change_serversettings',
+	                'show_element' => (
+	                    function_exists('apcu_cache_info') === true
+	                ),
+	            ),
+	            array (
+	                'url' => 'admin_opcacheinfo.php?page=showinfo',
+	                'label' => $lng['admin']['opcacheinfo'],
+	                'required_resources' => 'change_serversettings',
+	                'show_element' => (
+	                    function_exists('opcache_get_configuration') === true
+	                ),
+	            ),
+	        ),
+	    ),
 		'misc' => array (
 			'label' => $lng['admin']['misc'],
 			'elements' => array (
-				array (
-					'url' => 'admin_templates.php?page=email',
-					'label' => $lng['admin']['templates']['email'],
-				),
-				array (
-					'url' => 'admin_logger.php?page=log',
-					'label' => $lng['menue']['logger']['logger'],
-					'required_resources' => 'change_serversettings',
-					'show_element' => ( Settings::Get('logger.enabled') == true ),
-				),
+			    array (
+			        'url' => 'admin_settings.php?page=integritycheck',
+			        'label' => $lng['admin']['integritycheck'],
+			        'required_resources' => 'change_serversettings',
+			    ),
+			    array (
+			        'url' => 'admin_templates.php?page=email',
+			        'label' => $lng['admin']['templates']['email'],
+			    ),
 				array (
 					'url' => 'admin_message.php?page=message',
 					'label' => $lng['admin']['message'],
