@@ -259,7 +259,6 @@ $lng['admin']['admin_edit'] = 'Bewerk beheerder';
 $lng['admin']['customers_see_all'] = 'Kan alle klanten zien?';
 $lng['admin']['domains_see_all'] = 'Kan alle domeinen zien?';
 $lng['admin']['change_serversettings'] = 'Kan server instellingen aanpassen?';
-$lng['admin']['server'] = 'Server';
 $lng['admin']['serversettings'] = 'Instellingen';
 $lng['admin']['rebuildconf'] = 'Configuratie bestanden opnieuw aanmaken';
 $lng['admin']['stdsubdomain'] = 'Standaard subdomein';
@@ -689,10 +688,12 @@ $lng['serversettings']['logger']['types']['title'] = 'Log-type(s)';
 $lng['serversettings']['logger']['types']['description'] = 'Om meerdere types te selecteren, houd u CTRL ingedrukt terwijl u selecteert.<br />Beschikbare types zijn: syslog, bestand, mysql';
 $lng['serversettings']['logger']['logfile'] = 'Pad naar logfile, inclusief bestandsnaam';
 $lng['error']['logerror'] = 'Log-Fout: %s';
-$lng['serversettings']['logger']['logcron'] = 'Cronjobs loggen (eenmalig)';
+$lng['serversettings']['logger']['logcron'] = 'Cronjobs loggen';
+$lng['serversettings']['logger']['logcronoption']['never'] = 'Nooit';
+$lng['serversettings']['logger']['logcronoption']['once'] = 'Eeenmalig';
+$lng['serversettings']['logger']['logcronoption']['always'] = 'Altijd';
 $lng['question']['logger_reallytruncate'] = 'Weet u zeker dat u de tabel "%s" wilt legen?';
 $lng['admin']['loggersystem'] = 'Systeemlog';
-$lng['menue']['logger']['logger'] = 'Systeemlog';
 $lng['logger']['date'] = 'Datum';
 $lng['logger']['type'] = 'Type';
 $lng['logger']['action'] = 'Actie';
