@@ -291,7 +291,7 @@ $lng['admin']['admin_edit'] = 'Modifier un administrateur';
 $lng['admin']['customers_see_all'] = 'Peut voir tous les comptes ?';
 $lng['admin']['domains_see_all'] = 'Peut voir tous les Domaines ?';
 $lng['admin']['change_serversettings'] = 'Peut modifier la configuration du serveur ?';
-$lng['admin']['server'] = 'Serveur';
+$lng['admin']['server'] = 'Système';
 $lng['admin']['serversettings'] = 'Paramètres';
 $lng['admin']['rebuildconf'] = 'Régénérer la configuration';
 $lng['admin']['stdsubdomain'] = 'Sous-domaine type';
@@ -728,10 +728,12 @@ $lng['serversettings']['logger']['types']['title'] = 'Type(s) de log';
 $lng['serversettings']['logger']['types']['description'] = 'Spécifiez les types de log séparés par des virgules.<br />Les types de log disponible sont : syslog, file, mysql';
 $lng['serversettings']['logger']['logfile'] = 'Nom du fichier de log, dossier + nom du fichier';
 $lng['error']['logerror'] = 'Erreur log : %s';
-$lng['serversettings']['logger']['logcron'] = 'Loguer les travaux de cron (lancer une fois)';
+$lng['serversettings']['logger']['logcron'] = 'Loguer les travaux de cron';
+$lng['serversettings']['logger']['logcronoption']['never'] = 'Jamais';
+$lng['serversettings']['logger']['logcronoption']['once'] = 'Une fois';
+$lng['serversettings']['logger']['logcronoption']['always'] = 'Toujours';
 $lng['question']['logger_reallytruncate'] = 'Etes-vous sûr de vouloir vider la table "%s" ?';
 $lng['admin']['loggersystem'] = 'Log système';
-$lng['menue']['logger']['logger'] = 'Log système';
 $lng['logger']['date'] = 'Date';
 $lng['logger']['type'] = 'Type';
 $lng['logger']['action'] = 'Action';
